@@ -24,14 +24,8 @@ our @EXPORT_OK = qw/
 	set_text
 	sig_cmp
 	scalar_as_input
-	read_from_scalar
-	color_type_name
-	text_compression_name
 	get_libpng_ver
 	access_version_number
-	get_row_pointers
-	get_rows
-	get_rowbytes
 	get_valid
 	set_tRNS_pointer
 	set_rows
@@ -43,11 +37,9 @@ our @EXPORT_OK = qw/
 	libpng_supports
 	set_keep_unknown_chunks
 	get_tRNS_palette
-	set_PLTE_pointer
 	set_expand
 	set_gray_to_rgb
 	set_filler
-	get_sRGB
 	set_sRGB
 	set_packing
 	set_strip_16
@@ -101,7 +93,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.49_02';
+our $VERSION = '0.49_03';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
