@@ -137,7 +137,6 @@ typedef perl_libpng_t * Image__PNG__Libpng;
 static void
 perl_png_error_fn (png_structp png_ptr, png_const_charp error_msg)
 {
-    perl_libpng_t * png = png_get_error_ptr (png_ptr);
     /* An error from libpng sent via Perl's warning handler. */
     croak ("libpng error: %s\n", error_msg);
 }
@@ -147,7 +146,6 @@ perl_png_error_fn (png_structp png_ptr, png_const_charp error_msg)
 static void
 perl_png_warning_fn (png_structp png_ptr, png_const_charp warning_msg)
 {
-    perl_libpng_t * png = png_get_error_ptr (png_ptr);
     /* A warning from libpng sent via Perl's warning handler. */
     warn ( "libpng warning: %s\n", warning_msg);
 }
@@ -1190,13 +1188,6 @@ perl_png_set_PLTE (perl_libpng_t * png, AV * perl_colors)
     PERL_PNG_FREE (colors);
 }
 
-/* Set the palette directly, using a pointer. */
-
-static void
-perl_png_set_PLTE_pointer (perl_libpng_t * png, png_colorp colors, int n_colors){
-    png_set_PLTE (pngi, colors, n_colors);
-}
-
 /* Create a hash containing the colour values of a pointer to a
    png_color_16 structure. */
 
@@ -1467,7 +1458,7 @@ static SV * perl_png_get_tRNS (perl_libpng_t * png)
     else {
 	HV * trans_hv;
 	trans_hv = newHV ();
-#line 1470 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1461 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         
 	HASH_STORE_IV_MEMBER (trans_hv, red, trans_values);
 	
@@ -1477,7 +1468,7 @@ static SV * perl_png_get_tRNS (perl_libpng_t * png)
 	
 	HASH_STORE_IV_MEMBER (trans_hv, gray, trans_values);
 	
-#line 1475 "perl-libpng.c.tmpl"
+#line 1466 "perl-libpng.c.tmpl"
 	return newRV_noinc ((SV *) trans_hv);
     }
 #else
@@ -1495,7 +1486,6 @@ static void perl_png_set_tRNS (perl_libpng_t * png, SV * tRNS)
     png_byte color_type;
     png_byte trans[256] = {0};
     int num_trans;
-    png_uint_32 status;
     png_color_16 trans_values = {0};
     color_type = png_get_color_type (pngi);
     if (color_type & PNG_COLOR_MASK_PALETTE) {
@@ -1532,7 +1522,7 @@ static void perl_png_set_tRNS (perl_libpng_t * png, SV * tRNS)
 	    /* unhandled error */
 	}
 	trans_hv = (HV *) SvRV (tRNS);
-#line 1535 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1525 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         
 	    HASH_FETCH_IV_MEMBER (trans_hv, red, (& trans_values));
 	
@@ -1542,7 +1532,7 @@ static void perl_png_set_tRNS (perl_libpng_t * png, SV * tRNS)
 	
 	    HASH_FETCH_IV_MEMBER (trans_hv, gray, (& trans_values));
 	
-#line 1534 "perl-libpng.c.tmpl"
+#line 1524 "perl-libpng.c.tmpl"
 	num_trans = 1;
 	png_set_tRNS (pngi, trans, num_trans, & trans_values); 
     }
@@ -1570,14 +1560,14 @@ perl_png_spalette_to_hv (png_sPLT_tp spalette)
 	png_sPLT_entry * entry;
 	entry = spalette->entries + i;
 	perl_entry = newHV ();
-#line 1573 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1563 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 		HASH_STORE_IV_MEMBER (perl_entry, red, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, green, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, blue, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, alpha, entry);
 		HASH_STORE_IV_MEMBER (perl_entry, frequency, entry);
 	
-#line 1566 "perl-libpng.c.tmpl"
+#line 1556 "perl-libpng.c.tmpl"
 	av_push (entries, newRV_noinc ((SV *) perl_entry));
     }
     HASH_STORE_AV (perl_spalette, entries);
@@ -1681,14 +1671,14 @@ static void perl_png_set_sPLT (perl_libpng_t * png, AV * sPLT_entries)
 	    }
 	    MESSAGE ("Copying entry %d", j);
 	    e = entry->entries + j;
-#line 1684 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 1674 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
  	    	    HASH_FETCH_IV_MEMBER (perl_entry, red, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, green, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, blue, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, alpha, e);
 	    	    HASH_FETCH_IV_MEMBER (perl_entry, frequency, e);
 	    
-#line 1674 "perl-libpng.c.tmpl"
+#line 1664 "perl-libpng.c.tmpl"
 	}
     }
     MESSAGE ("Setting the entries");
@@ -1791,73 +1781,86 @@ static SV * perl_png_get_hIST (perl_libpng_t * png)
 
 static SV * perl_png_get_sBIT (perl_libpng_t * png)
 {
+    SV * sbit = & PL_sv_undef;
 #ifdef PNG_sBIT_SUPPORTED
     if (VALID (sBIT)) {
         HV * sig_bit;
         png_color_8p colors;
 	png_uint_32 status;
+	int color_type;
+
+	color_type = png_get_color_type (pngi);
         sig_bit = newHV ();
 	status = png_get_sBIT (pngi, & colors);
 	if (status != PNG_INFO_sBIT) {
-	    /* error */
+	    return sbit;
 	}
-#line 1804 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
-        
-	HASH_STORE_IV_MEMBER (sig_bit, red, colors);
-	
-	HASH_STORE_IV_MEMBER (sig_bit, green, colors);
-	
-	HASH_STORE_IV_MEMBER (sig_bit, blue, colors);
-	
-	HASH_STORE_IV_MEMBER (sig_bit, gray, colors);
-	
-	HASH_STORE_IV_MEMBER (sig_bit, alpha, colors);
-	
-#line 1791 "perl-libpng.c.tmpl"
-        return newRV_noinc ((SV *) sig_bit);
+	if ((color_type & PNG_COLOR_MASK_COLOR) != 0) {
+	    
+	    HASH_STORE_IV_MEMBER (sig_bit, red, colors);
+	    
+	    HASH_STORE_IV_MEMBER (sig_bit, green, colors);
+	    
+	    HASH_STORE_IV_MEMBER (sig_bit, blue, colors);
+	    
+	}
+	else {
+	    HASH_STORE_IV_MEMBER (sig_bit, gray, colors);
+	}
+	if ((color_type & PNG_COLOR_MASK_ALPHA) != 0) {
+	    HASH_STORE_IV_MEMBER (sig_bit, alpha, colors);
+	}
+        sbit = newRV_noinc ((SV *) sig_bit);
     }
-    return & PL_sv_undef;
 #else
     /* libpng was compiled without this option. */
     UNSUPPORTED(sBIT);
-    return & PL_sv_undef;
 #endif
+    return sbit;
 }
 
 static void perl_png_set_sBIT (perl_libpng_t * png, HV * sBIT)
 {
 #ifdef PNG_sBIT_SUPPORTED
     png_color_8 colors;
-     HASH_FETCH_IV_MEMBER (sBIT,red,(&colors)); HASH_FETCH_IV_MEMBER (sBIT,green,(&colors)); HASH_FETCH_IV_MEMBER (sBIT,blue,(&colors)); HASH_FETCH_IV_MEMBER (sBIT,gray,(&colors)); HASH_FETCH_IV_MEMBER (sBIT,alpha,(&colors));
+    
+    HASH_FETCH_IV_MEMBER (sBIT, red, (& colors));
+    
+    HASH_FETCH_IV_MEMBER (sBIT, green, (& colors));
+    
+    HASH_FETCH_IV_MEMBER (sBIT, blue, (& colors));
+    
+    HASH_FETCH_IV_MEMBER (sBIT, gray, (& colors));
+    
+    HASH_FETCH_IV_MEMBER (sBIT, alpha, (& colors));
+    
     png_set_sBIT (pngi, & colors);
 #else
-    /* libpng was compiled without this option. */
     UNSUPPORTED(sBIT);
 #endif
 }
 
 static SV * perl_png_get_oFFs (perl_libpng_t * png)
 {
+    SV * offs = & PL_sv_undef;
 #ifdef PNG_oFFs_SUPPORTED
     if (VALID (oFFs)) {
         HV * offset;
-        
-        png_int_32 x_offset;
+	png_int_32 x_offset;
         png_int_32 y_offset;
         int unit_type;
+
         offset = newHV ();
         png_get_oFFs (pngi, & x_offset, & y_offset, & unit_type);
         HASH_STORE_IV (offset, x_offset);
         HASH_STORE_IV (offset, y_offset);
         HASH_STORE_IV (offset, unit_type);
-        return newRV_noinc ((SV *) offset);
+        offs = newRV_noinc ((SV *) offset);
     }
-    return & PL_sv_undef;
 #else
-    /* libpng was compiled without this option. */
     UNSUPPORTED(oFFs);
-    return & PL_sv_undef;
 #endif
+    return offs;
 }
 
 /* set oFFs of PNG image. */
@@ -1873,13 +1876,13 @@ static void perl_png_set_oFFs (perl_libpng_t * png, HV * oFFs)
     HASH_FETCH_IV (oFFs, unit_type);
     png_set_oFFs (pngi, x_offset, y_offset, unit_type);
 #else
-    /* libpng was compiled without this option. */
     UNSUPPORTED(oFFs);
 #endif
 }
 
 static SV * perl_png_get_pHYs (perl_libpng_t * png)
 {
+    SV * physsv = & PL_sv_undef;
 #ifdef PNG_pHYs_SUPPORTED
     if (VALID (pHYs)) {
         png_uint_32 res_x;
@@ -1891,14 +1894,13 @@ static SV * perl_png_get_pHYs (perl_libpng_t * png)
         HASH_STORE_IV (phys, res_x);
         HASH_STORE_IV (phys, res_y);
         HASH_STORE_IV (phys, unit_type);
-        return newRV_noinc ((SV *) phys);
+        physsv = newRV_noinc ((SV *) phys);
     }
-    return & PL_sv_undef;
 #else
     /* libpng was compiled without this option. */
     UNSUPPORTED(pHYs);
-    return & PL_sv_undef;
 #endif
+    return physsv;
 }
 
 static void perl_png_set_pHYs (perl_libpng_t * png, HV * pHYs)
@@ -1995,9 +1997,9 @@ static SV * perl_png_get_valid (perl_libpng_t * png)
     valid = png_get_valid (pngi, 0xFFFFFFFF);
 #define V(x) \
     (void) hv_store (perl_valid, #x, strlen (#x), newSViv (valid & PNG_INFO_ ## x), 0)
-#line 1998 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 2000 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 V(bKGD);V(cHRM);V(gAMA);V(hIST);V(iCCP);V(IDAT);V(oFFs);V(pCAL);V(pHYs);V(PLTE);V(sBIT);V(sCAL);V(sPLT);V(sRGB);V(tIME);V(tRNS);
-#line 1975 "perl-libpng.c.tmpl"
+#line 1973 "perl-libpng.c.tmpl"
 #undef V
 
     return newRV_noinc ((SV *) perl_valid);
@@ -2017,7 +2019,6 @@ perl_png_get_rows (perl_libpng_t * png)
     png_bytepp rows;
     int rowbytes;
     int height;
-    SV ** row_svs;
     int r;
     AV * perl_rows;
 
@@ -2095,8 +2096,6 @@ perl_png_read_image (perl_libpng_t * png)
         png->row_pointers[i] = png->image_data + rowbytes * i;
     }
     png_read_image (png->png, png->row_pointers);
-    /* Set the row_pointers pointers to point into the allocated
-       memory. */
 }
 
 /* Get the row pointers directly. */
@@ -2191,6 +2190,7 @@ static void perl_png_set_rows (perl_libpng_t * png, AV * rows)
 	r += rbytes;
     }
     if (r != ar + arbytes) {
+	/* Final check after writing row data. */
 	croak ("%s:%d: Mismatch %p != %p", __FILE__, __LINE__,
 	       r, ar + arbytes);
     }
@@ -2372,96 +2372,47 @@ static void perl_png_set_unknown_chunks (perl_libpng_t * png, AV * chunk_list)
 int perl_png_libpng_supports (const char * what)
 {
 #line 2374 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
-    if (strcmp (what, "iTXt") == 0) {
-#ifdef PNG_iTXt_SUPPORTED
+    if (strcmp (what, "16BIT") == 0) {
+#ifdef PNG_16BIT_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* iTXt */
+#endif /* 16BIT */
     }
-    if (strcmp (what, "UNKNOWN_CHUNKS") == 0) {
-#ifdef PNG_UNKNOWN_CHUNKS_SUPPORTED
+    if (strcmp (what, "ALIGNED_MEMORY") == 0) {
+#ifdef PNG_ALIGNED_MEMORY_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* UNKNOWN_CHUNKS */
+#endif /* ALIGNED_MEMORY */
     }
-    if (strcmp (what, "zTXt") == 0) {
-#ifdef PNG_zTXt_SUPPORTED
+    if (strcmp (what, "ARM_NEON_API") == 0) {
+#ifdef PNG_ARM_NEON_API_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* zTXt */
+#endif /* ARM_NEON_API */
     }
-    if (strcmp (what, "tEXt") == 0) {
-#ifdef PNG_tEXt_SUPPORTED
+    if (strcmp (what, "BENIGN_ERRORS") == 0) {
+#ifdef PNG_BENIGN_ERRORS_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* tEXt */
+#endif /* BENIGN_ERRORS */
     }
-    if (strcmp (what, "pCAL") == 0) {
-#ifdef PNG_pCAL_SUPPORTED
+    if (strcmp (what, "BENIGN_READ_ERRORS") == 0) {
+#ifdef PNG_BENIGN_READ_ERRORS_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* pCAL */
+#endif /* BENIGN_READ_ERRORS */
     }
-    if (strcmp (what, "iCCP") == 0) {
-#ifdef PNG_iCCP_SUPPORTED
+    if (strcmp (what, "BENIGN_WRITE_ERRORS") == 0) {
+#ifdef PNG_BENIGN_WRITE_ERRORS_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* iCCP */
-    }
-    if (strcmp (what, "sPLT") == 0) {
-#ifdef PNG_sPLT_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* sPLT */
-    }
-    if (strcmp (what, "USER_LIMITS") == 0) {
-#ifdef PNG_USER_LIMITS_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* USER_LIMITS */
-    }
-    if (strcmp (what, "tIME") == 0) {
-#ifdef PNG_tIME_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* tIME */
-    }
-    if (strcmp (what, "TEXT") == 0) {
-#ifdef PNG_TEXT_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* TEXT */
-    }
-    if (strcmp (what, "HANDLE_AS_UNKNOWN") == 0) {
-#ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* HANDLE_AS_UNKNOWN */
-    }
-    if (strcmp (what, "USER_CHUNKS") == 0) {
-#ifdef PNG_USER_CHUNKS_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* USER_CHUNKS */
-    }
-    if (strcmp (what, "CONVERT_tIME") == 0) {
-#ifdef PNG_CONVERT_tIME_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* CONVERT_tIME */
+#endif /* BENIGN_WRITE_ERRORS */
     }
     if (strcmp (what, "bKGD") == 0) {
 #ifdef PNG_bKGD_SUPPORTED
@@ -2469,6 +2420,27 @@ int perl_png_libpng_supports (const char * what)
 #else
         return 0;
 #endif /* bKGD */
+    }
+    if (strcmp (what, "BUILD_GRAYSCALE_PALETTE") == 0) {
+#ifdef PNG_BUILD_GRAYSCALE_PALETTE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* BUILD_GRAYSCALE_PALETTE */
+    }
+    if (strcmp (what, "BUILTIN_BSWAP16") == 0) {
+#ifdef PNG_BUILTIN_BSWAP16_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* BUILTIN_BSWAP16 */
+    }
+    if (strcmp (what, "CHECK_FOR_INVALID_INDEX") == 0) {
+#ifdef PNG_CHECK_FOR_INVALID_INDEX_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* CHECK_FOR_INVALID_INDEX */
     }
     if (strcmp (what, "cHRM") == 0) {
 #ifdef PNG_cHRM_SUPPORTED
@@ -2477,68 +2449,54 @@ int perl_png_libpng_supports (const char * what)
         return 0;
 #endif /* cHRM */
     }
-    if (strcmp (what, "gAMA") == 0) {
-#ifdef PNG_gAMA_SUPPORTED
+    if (strcmp (what, "COLORSPACE") == 0) {
+#ifdef PNG_COLORSPACE_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* gAMA */
+#endif /* COLORSPACE */
     }
-    if (strcmp (what, "hIST") == 0) {
-#ifdef PNG_hIST_SUPPORTED
+    if (strcmp (what, "CONSOLE_IO") == 0) {
+#ifdef PNG_CONSOLE_IO_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* hIST */
+#endif /* CONSOLE_IO */
     }
-    if (strcmp (what, "oFFs") == 0) {
-#ifdef PNG_oFFs_SUPPORTED
+    if (strcmp (what, "CONVERT_tIME") == 0) {
+#ifdef PNG_CONVERT_tIME_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* oFFs */
+#endif /* CONVERT_tIME */
     }
-    if (strcmp (what, "pHYs") == 0) {
-#ifdef PNG_pHYs_SUPPORTED
+    if (strcmp (what, "CONVERT_tIME") == 0) {
+#ifdef PNG_CONVERT_tIME_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* pHYs */
+#endif /* CONVERT_tIME */
     }
-    if (strcmp (what, "sBIT") == 0) {
-#ifdef PNG_sBIT_SUPPORTED
+    if (strcmp (what, "EASY_ACCESS") == 0) {
+#ifdef PNG_EASY_ACCESS_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* sBIT */
+#endif /* EASY_ACCESS */
     }
-    if (strcmp (what, "sRGB") == 0) {
-#ifdef PNG_sRGB_SUPPORTED
+    if (strcmp (what, "ERROR_NUMBERS") == 0) {
+#ifdef PNG_ERROR_NUMBERS_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* sRGB */
+#endif /* ERROR_NUMBERS */
     }
-    if (strcmp (what, "tRNS") == 0) {
-#ifdef PNG_tRNS_SUPPORTED
+    if (strcmp (what, "ERROR_TEXT") == 0) {
+#ifdef PNG_ERROR_TEXT_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* tRNS */
-    }
-    if (strcmp (what, "WRITE_CUSTOMIZE_ZTXT_COMPRESSION") == 0) {
-#ifdef PNG_WRITE_CUSTOMIZE_ZTXT_COMPRESSION_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* WRITE_CUSTOMIZE_ZTXT_COMPRESSION */
-    }
-    if (strcmp (what, "WRITE_CUSTOMIZE_COMPRESSION") == 0) {
-#ifdef PNG_WRITE_CUSTOMIZE_COMPRESSION_SUPPORTED
-        return 1;
-#else
-        return 0;
-#endif /* WRITE_CUSTOMIZE_COMPRESSION */
+#endif /* ERROR_TEXT */
     }
     if (strcmp (what, "eXIf") == 0) {
 #ifdef PNG_eXIf_SUPPORTED
@@ -2547,28 +2505,784 @@ int perl_png_libpng_supports (const char * what)
         return 0;
 #endif /* eXIf */
     }
-    if (strcmp (what, "gIFg") == 0) {
-#ifdef PNG_gIFg_SUPPORTED
+    if (strcmp (what, "FIXED_POINT") == 0) {
+#ifdef PNG_FIXED_POINT_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* gIFg */
+#endif /* FIXED_POINT */
     }
-    if (strcmp (what, "gIFx") == 0) {
-#ifdef PNG_gIFx_SUPPORTED
+    if (strcmp (what, "FIXED_POINT_MACRO") == 0) {
+#ifdef PNG_FIXED_POINT_MACRO_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* gIFx */
+#endif /* FIXED_POINT_MACRO */
     }
-    if (strcmp (what, "sTER") == 0) {
-#ifdef PNG_sTER_SUPPORTED
+    if (strcmp (what, "FLOATING_ARITHMETIC") == 0) {
+#ifdef PNG_FLOATING_ARITHMETIC_SUPPORTED
         return 1;
 #else
         return 0;
-#endif /* sTER */
+#endif /* FLOATING_ARITHMETIC */
     }
-#line 2366 "perl-libpng.c.tmpl"
+    if (strcmp (what, "FLOATING_POINT") == 0) {
+#ifdef PNG_FLOATING_POINT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* FLOATING_POINT */
+    }
+    if (strcmp (what, "FORMAT_AFIRST") == 0) {
+#ifdef PNG_FORMAT_AFIRST_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* FORMAT_AFIRST */
+    }
+    if (strcmp (what, "FORMAT_BGR") == 0) {
+#ifdef PNG_FORMAT_BGR_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* FORMAT_BGR */
+    }
+    if (strcmp (what, "gAMA") == 0) {
+#ifdef PNG_gAMA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* gAMA */
+    }
+    if (strcmp (what, "GAMMA") == 0) {
+#ifdef PNG_GAMMA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* GAMMA */
+    }
+    if (strcmp (what, "GET_PALETTE_MAX") == 0) {
+#ifdef PNG_GET_PALETTE_MAX_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* GET_PALETTE_MAX */
+    }
+    if (strcmp (what, "HANDLE_AS_UNKNOWN") == 0) {
+#ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* HANDLE_AS_UNKNOWN */
+    }
+    if (strcmp (what, "HANDLE_AS_UNKNOWN") == 0) {
+#ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* HANDLE_AS_UNKNOWN */
+    }
+    if (strcmp (what, "hIST") == 0) {
+#ifdef PNG_hIST_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* hIST */
+    }
+    if (strcmp (what, "iCCP") == 0) {
+#ifdef PNG_iCCP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* iCCP */
+    }
+    if (strcmp (what, "INCH_CONVERSIONS") == 0) {
+#ifdef PNG_INCH_CONVERSIONS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* INCH_CONVERSIONS */
+    }
+    if (strcmp (what, "INFO_IMAGE") == 0) {
+#ifdef PNG_INFO_IMAGE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* INFO_IMAGE */
+    }
+    if (strcmp (what, "IO_STATE") == 0) {
+#ifdef PNG_IO_STATE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* IO_STATE */
+    }
+    if (strcmp (what, "iTXt") == 0) {
+#ifdef PNG_iTXt_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* iTXt */
+    }
+    if (strcmp (what, "MIPS_MSA_API") == 0) {
+#ifdef PNG_MIPS_MSA_API_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* MIPS_MSA_API */
+    }
+    if (strcmp (what, "MNG_FEATURES") == 0) {
+#ifdef PNG_MNG_FEATURES_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* MNG_FEATURES */
+    }
+    if (strcmp (what, "oFFs") == 0) {
+#ifdef PNG_oFFs_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* oFFs */
+    }
+    if (strcmp (what, "pCAL") == 0) {
+#ifdef PNG_pCAL_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* pCAL */
+    }
+    if (strcmp (what, "PEDANTIC_WARNINGS") == 0) {
+#ifdef PNG_PEDANTIC_WARNINGS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* PEDANTIC_WARNINGS */
+    }
+    if (strcmp (what, "pHYs") == 0) {
+#ifdef PNG_pHYs_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* pHYs */
+    }
+    if (strcmp (what, "POINTER_INDEXING") == 0) {
+#ifdef PNG_POINTER_INDEXING_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* POINTER_INDEXING */
+    }
+    if (strcmp (what, "POWERPC_VSX_API") == 0) {
+#ifdef PNG_POWERPC_VSX_API_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* POWERPC_VSX_API */
+    }
+    if (strcmp (what, "PROGRESSIVE_READ") == 0) {
+#ifdef PNG_PROGRESSIVE_READ_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* PROGRESSIVE_READ */
+    }
+    if (strcmp (what, "READ") == 0) {
+#ifdef PNG_READ_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ */
+    }
+    if (strcmp (what, "READ_16_TO_8") == 0) {
+#ifdef PNG_READ_16_TO_8_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_16_TO_8 */
+    }
+    if (strcmp (what, "READ_ALPHA_MODE") == 0) {
+#ifdef PNG_READ_ALPHA_MODE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_ALPHA_MODE */
+    }
+    if (strcmp (what, "READ_BACKGROUND") == 0) {
+#ifdef PNG_READ_BACKGROUND_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_BACKGROUND */
+    }
+    if (strcmp (what, "READ_BGR") == 0) {
+#ifdef PNG_READ_BGR_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_BGR */
+    }
+    if (strcmp (what, "READ_COMPOSITE_NODIV") == 0) {
+#ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_COMPOSITE_NODIV */
+    }
+    if (strcmp (what, "READ_COMPRESSED_TEXT") == 0) {
+#ifdef PNG_READ_COMPRESSED_TEXT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_COMPRESSED_TEXT */
+    }
+    if (strcmp (what, "READ_EXPAND") == 0) {
+#ifdef PNG_READ_EXPAND_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_EXPAND */
+    }
+    if (strcmp (what, "READ_EXPAND_16") == 0) {
+#ifdef PNG_READ_EXPAND_16_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_EXPAND_16 */
+    }
+    if (strcmp (what, "READ_FILLER") == 0) {
+#ifdef PNG_READ_FILLER_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_FILLER */
+    }
+    if (strcmp (what, "READ_GRAY_TO_RGB") == 0) {
+#ifdef PNG_READ_GRAY_TO_RGB_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_GRAY_TO_RGB */
+    }
+    if (strcmp (what, "READ_INTERLACING") == 0) {
+#ifdef PNG_READ_INTERLACING_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_INTERLACING */
+    }
+    if (strcmp (what, "READ_INT_FUNCTIONS") == 0) {
+#ifdef PNG_READ_INT_FUNCTIONS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_INT_FUNCTIONS */
+    }
+    if (strcmp (what, "READ_INVERT") == 0) {
+#ifdef PNG_READ_INVERT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_INVERT */
+    }
+    if (strcmp (what, "READ_INVERT_ALPHA") == 0) {
+#ifdef PNG_READ_INVERT_ALPHA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_INVERT_ALPHA */
+    }
+    if (strcmp (what, "READ_OPT_PLTE") == 0) {
+#ifdef PNG_READ_OPT_PLTE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_OPT_PLTE */
+    }
+    if (strcmp (what, "READ_PACK") == 0) {
+#ifdef PNG_READ_PACK_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_PACK */
+    }
+    if (strcmp (what, "READ_PACKSWAP") == 0) {
+#ifdef PNG_READ_PACKSWAP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_PACKSWAP */
+    }
+    if (strcmp (what, "READ_QUANTIZE") == 0) {
+#ifdef PNG_READ_QUANTIZE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_QUANTIZE */
+    }
+    if (strcmp (what, "READ_RGB_TO_GRAY") == 0) {
+#ifdef PNG_READ_RGB_TO_GRAY_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_RGB_TO_GRAY */
+    }
+    if (strcmp (what, "READ_SCALE_16_TO_8") == 0) {
+#ifdef PNG_READ_SCALE_16_TO_8_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_SCALE_16_TO_8 */
+    }
+    if (strcmp (what, "READ_SHIFT") == 0) {
+#ifdef PNG_READ_SHIFT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_SHIFT */
+    }
+    if (strcmp (what, "READ_STRIP_16_TO_8") == 0) {
+#ifdef PNG_READ_STRIP_16_TO_8_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_STRIP_16_TO_8 */
+    }
+    if (strcmp (what, "READ_STRIP_ALPHA") == 0) {
+#ifdef PNG_READ_STRIP_ALPHA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_STRIP_ALPHA */
+    }
+    if (strcmp (what, "READ_SWAP") == 0) {
+#ifdef PNG_READ_SWAP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_SWAP */
+    }
+    if (strcmp (what, "READ_SWAP_ALPHA") == 0) {
+#ifdef PNG_READ_SWAP_ALPHA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_SWAP_ALPHA */
+    }
+    if (strcmp (what, "READ_tEXt") == 0) {
+#ifdef PNG_READ_tEXt_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_tEXt */
+    }
+    if (strcmp (what, "READ_TRANSFORMS") == 0) {
+#ifdef PNG_READ_TRANSFORMS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_TRANSFORMS */
+    }
+    if (strcmp (what, "READ_USER_TRANSFORM") == 0) {
+#ifdef PNG_READ_USER_TRANSFORM_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_USER_TRANSFORM */
+    }
+    if (strcmp (what, "READ_zTXt") == 0) {
+#ifdef PNG_READ_zTXt_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* READ_zTXt */
+    }
+    if (strcmp (what, "SAVE_INT_32") == 0) {
+#ifdef PNG_SAVE_INT_32_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SAVE_INT_32 */
+    }
+    if (strcmp (what, "SAVE_UNKNOWN_CHUNKS") == 0) {
+#ifdef PNG_SAVE_UNKNOWN_CHUNKS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SAVE_UNKNOWN_CHUNKS */
+    }
+    if (strcmp (what, "sBIT") == 0) {
+#ifdef PNG_sBIT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* sBIT */
+    }
+    if (strcmp (what, "sCAL") == 0) {
+#ifdef PNG_sCAL_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* sCAL */
+    }
+    if (strcmp (what, "SEQUENTIAL_READ") == 0) {
+#ifdef PNG_SEQUENTIAL_READ_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SEQUENTIAL_READ */
+    }
+    if (strcmp (what, "SETJMP") == 0) {
+#ifdef PNG_SETJMP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SETJMP */
+    }
+    if (strcmp (what, "SET_OPTION") == 0) {
+#ifdef PNG_SET_OPTION_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SET_OPTION */
+    }
+    if (strcmp (what, "SET_UNKNOWN_CHUNKS") == 0) {
+#ifdef PNG_SET_UNKNOWN_CHUNKS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SET_UNKNOWN_CHUNKS */
+    }
+    if (strcmp (what, "SET_USER_LIMITS") == 0) {
+#ifdef PNG_SET_USER_LIMITS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SET_USER_LIMITS */
+    }
+    if (strcmp (what, "SIMPLIFIED_READ") == 0) {
+#ifdef PNG_SIMPLIFIED_READ_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_READ */
+    }
+    if (strcmp (what, "SIMPLIFIED_READ_AFIRST") == 0) {
+#ifdef PNG_SIMPLIFIED_READ_AFIRST_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_READ_AFIRST */
+    }
+    if (strcmp (what, "SIMPLIFIED_WRITE") == 0) {
+#ifdef PNG_SIMPLIFIED_WRITE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_WRITE */
+    }
+    if (strcmp (what, "SIMPLIFIED_WRITE_AFIRST") == 0) {
+#ifdef PNG_SIMPLIFIED_WRITE_AFIRST_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_WRITE_AFIRST */
+    }
+    if (strcmp (what, "SIMPLIFIED_WRITE_BGR") == 0) {
+#ifdef PNG_SIMPLIFIED_WRITE_BGR_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_WRITE_BGR */
+    }
+    if (strcmp (what, "SIMPLIFIED_WRITE_STDIO") == 0) {
+#ifdef PNG_SIMPLIFIED_WRITE_STDIO_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* SIMPLIFIED_WRITE_STDIO */
+    }
+    if (strcmp (what, "sPLT") == 0) {
+#ifdef PNG_sPLT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* sPLT */
+    }
+    if (strcmp (what, "sRGB") == 0) {
+#ifdef PNG_sRGB_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* sRGB */
+    }
+    if (strcmp (what, "STDIO") == 0) {
+#ifdef PNG_STDIO_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* STDIO */
+    }
+    if (strcmp (what, "STORE_UNKNOWN_CHUNKS") == 0) {
+#ifdef PNG_STORE_UNKNOWN_CHUNKS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* STORE_UNKNOWN_CHUNKS */
+    }
+    if (strcmp (what, "TEXT") == 0) {
+#ifdef PNG_TEXT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* TEXT */
+    }
+    if (strcmp (what, "tEXt") == 0) {
+#ifdef PNG_tEXt_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* tEXt */
+    }
+    if (strcmp (what, "tIME") == 0) {
+#ifdef PNG_tIME_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* tIME */
+    }
+    if (strcmp (what, "TIME_RFC1123") == 0) {
+#ifdef PNG_TIME_RFC1123_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* TIME_RFC1123 */
+    }
+    if (strcmp (what, "tRNS") == 0) {
+#ifdef PNG_tRNS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* tRNS */
+    }
+    if (strcmp (what, "UNKNOWN_CHUNKS") == 0) {
+#ifdef PNG_UNKNOWN_CHUNKS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* UNKNOWN_CHUNKS */
+    }
+    if (strcmp (what, "USER_CHUNKS") == 0) {
+#ifdef PNG_USER_CHUNKS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_CHUNKS */
+    }
+    if (strcmp (what, "USER_LIMITS") == 0) {
+#ifdef PNG_USER_LIMITS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_LIMITS */
+    }
+    if (strcmp (what, "USER_LIMITS") == 0) {
+#ifdef PNG_USER_LIMITS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_LIMITS */
+    }
+    if (strcmp (what, "USER_MEM") == 0) {
+#ifdef PNG_USER_MEM_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_MEM */
+    }
+    if (strcmp (what, "USER_TRANSFORM_INFO") == 0) {
+#ifdef PNG_USER_TRANSFORM_INFO_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_TRANSFORM_INFO */
+    }
+    if (strcmp (what, "USER_TRANSFORM_PTR") == 0) {
+#ifdef PNG_USER_TRANSFORM_PTR_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* USER_TRANSFORM_PTR */
+    }
+    if (strcmp (what, "WARNINGS") == 0) {
+#ifdef PNG_WARNINGS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WARNINGS */
+    }
+    if (strcmp (what, "WRITE") == 0) {
+#ifdef PNG_WRITE_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE */
+    }
+    if (strcmp (what, "WRITE_BGR") == 0) {
+#ifdef PNG_WRITE_BGR_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_BGR */
+    }
+    if (strcmp (what, "WRITE_COMPRESSED_TEXT") == 0) {
+#ifdef PNG_WRITE_COMPRESSED_TEXT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_COMPRESSED_TEXT */
+    }
+    if (strcmp (what, "WRITE_CUSTOMIZE_COMPRESSION") == 0) {
+#ifdef PNG_WRITE_CUSTOMIZE_COMPRESSION_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_CUSTOMIZE_COMPRESSION */
+    }
+    if (strcmp (what, "WRITE_CUSTOMIZE_ZTXT_COMPRESSION") == 0) {
+#ifdef PNG_WRITE_CUSTOMIZE_ZTXT_COMPRESSION_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_CUSTOMIZE_ZTXT_COMPRESSION */
+    }
+    if (strcmp (what, "WRITE_FILLER") == 0) {
+#ifdef PNG_WRITE_FILLER_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_FILLER */
+    }
+    if (strcmp (what, "WRITE_FILTER") == 0) {
+#ifdef PNG_WRITE_FILTER_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_FILTER */
+    }
+    if (strcmp (what, "WRITE_FLUSH") == 0) {
+#ifdef PNG_WRITE_FLUSH_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_FLUSH */
+    }
+    if (strcmp (what, "WRITE_FLUSH_AFTER_IEND") == 0) {
+#ifdef PNG_WRITE_FLUSH_AFTER_IEND_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_FLUSH_AFTER_IEND */
+    }
+    if (strcmp (what, "WRITE_INTERLACING") == 0) {
+#ifdef PNG_WRITE_INTERLACING_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_INTERLACING */
+    }
+    if (strcmp (what, "WRITE_INT_FUNCTIONS") == 0) {
+#ifdef PNG_WRITE_INT_FUNCTIONS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_INT_FUNCTIONS */
+    }
+    if (strcmp (what, "WRITE_INVERT") == 0) {
+#ifdef PNG_WRITE_INVERT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_INVERT */
+    }
+    if (strcmp (what, "WRITE_INVERT_ALPHA") == 0) {
+#ifdef PNG_WRITE_INVERT_ALPHA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_INVERT_ALPHA */
+    }
+    if (strcmp (what, "WRITE_OPTIMIZE_CMF") == 0) {
+#ifdef PNG_WRITE_OPTIMIZE_CMF_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_OPTIMIZE_CMF */
+    }
+    if (strcmp (what, "WRITE_PACK") == 0) {
+#ifdef PNG_WRITE_PACK_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_PACK */
+    }
+    if (strcmp (what, "WRITE_PACKSWAP") == 0) {
+#ifdef PNG_WRITE_PACKSWAP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_PACKSWAP */
+    }
+    if (strcmp (what, "WRITE_SHIFT") == 0) {
+#ifdef PNG_WRITE_SHIFT_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_SHIFT */
+    }
+    if (strcmp (what, "WRITE_SWAP") == 0) {
+#ifdef PNG_WRITE_SWAP_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_SWAP */
+    }
+    if (strcmp (what, "WRITE_SWAP_ALPHA") == 0) {
+#ifdef PNG_WRITE_SWAP_ALPHA_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_SWAP_ALPHA */
+    }
+    if (strcmp (what, "WRITE_TRANSFORMS") == 0) {
+#ifdef PNG_WRITE_TRANSFORMS_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_TRANSFORMS */
+    }
+    if (strcmp (what, "WRITE_USER_TRANSFORM") == 0) {
+#ifdef PNG_WRITE_USER_TRANSFORM_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_USER_TRANSFORM */
+    }
+    if (strcmp (what, "WRITE_WEIGHTED_FILTER") == 0) {
+#ifdef PNG_WRITE_WEIGHTED_FILTER_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* WRITE_WEIGHTED_FILTER */
+    }
+    if (strcmp (what, "zTXt") == 0) {
+#ifdef PNG_zTXt_SUPPORTED
+        return 1;
+#else
+        return 0;
+#endif /* zTXt */
+    }
+#line 2355 "perl-libpng.c.tmpl"
 
     /* sCAL is a special case. */
 
@@ -2578,10 +3292,26 @@ int perl_png_libpng_supports (const char * what)
 #else
         return 0;
 #endif /* sCAL */
+    }
+    /* These were in the module prior to 0.50, even though there is no
+       such macro in libpng. */
+    if (strcmp (what, "zTXt") == 0) {
+#if defined(PNG_READ_zTXt_SUPPORTED) && defined(PNG_WRITE_zTXt_SUPPORTED)
+	return 1;
+#else
+	return 0;
+#endif
+    }
+    if (strcmp (what, "tEXt") == 0) {
+#if defined(PNG_READ_tEXt_SUPPORTED) && defined(PNG_WRITE_tEXt_SUPPORTED)
+	return 1;
+#else
+	return 0;
+#endif
     }
     /* The user asked whether something was supported, but we don't
        know what that thing is. */
-    warn ( "Unknown whether '%s' is supported", what);
+    warn ("Unknown whether '%s' is supported", what);
     return 0;
 }
 
@@ -2645,36 +3375,13 @@ perl_png_set_keep_unknown_chunks (perl_libpng_t * png, int keep,
 #endif
 }
 
-static void
-perl_png_set_expand (perl_libpng_t * png)
-{
-    png_set_expand (png->png);
-}
-
-static void
-perl_png_set_gray_to_rgb (perl_libpng_t * png)
-{
-    png_set_gray_to_rgb(png->png);
-}
-
-static void
-perl_png_set_filler (perl_libpng_t * png, int filler, int flags)
-{
-    png_set_filler (png->png, filler, flags);
-}
-
-static void
-perl_png_set_strip_16 (perl_libpng_t * png)
-{
-    png_set_strip_16 (png->png);
-}
-
 static SV * perl_png_get_cHRM (perl_libpng_t * png)
 {
+    SV * chrm = & PL_sv_undef; 
 #ifdef PNG_cHRM_SUPPORTED
     if (VALID (cHRM)) {
         HV * ice;
-#line 2677 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3384 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         double white_x;
         double white_y;
         double red_x;
@@ -2683,10 +3390,10 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
         double green_y;
         double blue_x;
         double blue_y;
-#line 2476 "perl-libpng.c.tmpl"
+#line 2453 "perl-libpng.c.tmpl"
         png_get_cHRM (pngi , & white_x, & white_y, & red_x, & red_y, & green_x, & green_y, & blue_x, & blue_y);
         ice = newHV ();
-#line 2689 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3396 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
         (void) hv_store (ice, "white_x", strlen ("white_x"),
                          newSVnv (white_x), 0);
         (void) hv_store (ice, "white_y", strlen ("white_y"),
@@ -2703,22 +3410,21 @@ static SV * perl_png_get_cHRM (perl_libpng_t * png)
                          newSVnv (blue_x), 0);
         (void) hv_store (ice, "blue_y", strlen ("blue_y"),
                          newSVnv (blue_y), 0);
-#line 2485 "perl-libpng.c.tmpl"
-        return newRV_noinc ((SV *) ice);
+#line 2462 "perl-libpng.c.tmpl"
+        chrm = newRV_noinc ((SV *) ice);
     }
-    return & PL_sv_undef;
 #else
     /* libpng was compiled without this option. */
     UNSUPPORTED(cHRM);
-    return & PL_sv_undef;
 #endif
+    return chrm;
 }
 
 static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
 {
 #ifdef PNG_cHRM_SUPPORTED
     SV ** key_sv_ptr;
-#line 2721 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3427 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
     double white_x = 0.0;
     double white_y = 0.0;
     double red_x = 0.0;
@@ -2759,9 +3465,9 @@ static void perl_png_set_cHRM (perl_libpng_t * png, HV * cHRM)
     if (key_sv_ptr) {
         blue_y = SvNV (* key_sv_ptr);
     }
-#line 2510 "perl-libpng.c.tmpl"
+#line 2486 "perl-libpng.c.tmpl"
     png_set_cHRM (pngi, white_x, white_y, red_x, red_y, green_x, green_y, blue_x, blue_y);
-#line 2513 "perl-libpng.c.tmpl"
+#line 2489 "perl-libpng.c.tmpl"
 #else
     /* libpng was compiled without this option. */
     UNSUPPORTED(cHRM);
@@ -2795,7 +3501,7 @@ static void perl_png_copy_row_pointers (perl_libpng_t * png, SV * row_pointers)
     png_set_rows (pngi, png->row_pointers);
 }
 
-#line 2798 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
+#line 3504 "/usr/home/ben/projects/image-png-libpng/build/../perl-libpng.c"
 
 static int
 perl_png_get_image_width (perl_libpng_t * png)
@@ -2809,7 +3515,7 @@ perl_png_get_image_height (perl_libpng_t * png)
     return png_get_image_height (pngi);
 }
 
-#line 2555 "perl-libpng.c.tmpl"
+#line 2531 "perl-libpng.c.tmpl"
 
 
 static void
